==> miniorange_2fa-8.x-1.1.tar.gz: miniorange_2fa/src/Form/test_otp_over_email.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

/**
 * @file
 * OTP Over Email(test) functions.
 */
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;
/**
 * Menu callback for testing OTP Over Email.
 */
class test_otp_over_email extends FormBase
{
    public function getFormId() {
        return 'miniorange_otp_over_email';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['markup_top_2'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
        );

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        global $base_url;
        $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $custom_attribute = MoAuthUtilities::get_users_custom_attribute($user_id);
        $user_email = $custom_attribute[0]->miniorange_registered_email;
        $user_phone = \Drupal::config('miniorange_2fa.settings')->get('mo_phone');
        $authTypeCode = AuthenticationType::$OTP_OVER_EMAIL['code'];

        $txId_Value = \Drupal::config('miniorange_2fa.settings')->get('txId_Value');
        if($txId_Value == 'EMPTY_VALUE') {
            $messageHeader = 'An OTP has been sent to ' . $user_email . '. Please enter it here to complete the test.';
            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), NULL, $user_phone, NULL, $authTypeCode, $user_email);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->challenge($miniorange_user);
            if(isset($response->status) && $response->status != 'SUCCESS') {
                $message = 'An error occured while sending passcode. <em>('.$response->message.')</em>';
                MoAuthUtilities::show_error_or_success_message($message , 'error');
            } else{
                drupal_set_message(t($messageHeader), 'status');
            }
            //Store txId
            \Drupal::configFactory()->getEditable('miniorange_2fa.settings')->set('txId_Value', $response->txId)->save();
        }

        $form['header']['#markup'] = '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Test OTP Over Email</div></div>';

        $form['mo_auth_otpover_email_token'] = array(
            '#type' => 'textfield',
            '#maxlength' => 6,
            '#attributes' => array(
                'placeholder' => t('Enter 6 digit passcode.'),
                'class' => array(
                    'mo2f-textbox',
                    'mo2f-textbox-otp'
                ),
                'style' => 'width:200px',
                'autofocus' => 'true'
            ),
        );

        $form['actions_form_submit'] = array(
            '#type' => 'submit',
            '#value' => t('Verify')
        );

        $form['actions_form_cancel'] = array(
            '#markup' => '<span>&nbsp;&nbsp;</span><a href="'.$url.' "> Cancel Test</a>',
        );

        $form['main_layout_div_end'] = array(
            '#markup' => '<br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br></div>',
        );

        MoAuthUtilities::AddsupportTab( $form, $form_state);

        return $form;
    }

    /**
     * Form submit handler for otp over sms validation.
     */
    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        // Clear all the messages
        drupal_get_messages();

        $txId = \Drupal::config('miniorange_2fa.settings')->get('txId_Value');
        $token = $form['mo_auth_otpover_email_token']['#value'];
        if(empty($token)){
            drupal_set_message(t('Please enter passcode first.'), 'error');
            return;
        }

        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $custom_attribute = MoAuthUtilities::get_users_custom_attribute($user_id);
        $user_email = $custom_attribute[0]->miniorange_registered_email;
        $authTypeCode = AuthenticationType::$OTP_OVER_EMAIL['code'];
        $user_phone = \Drupal::config('miniorange_2fa.settings')->get('mo_phone');

        $customer = new MiniorangeCustomerProfile();
        $miniorange_user = new MiniorangeUser($customer->getCustomerID(), NULL, $user_phone, $authTypeCode, $user_email);
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->validate($miniorange_user, $txId, $token);

        // read API response
        if ($response->status == 'SUCCESS') {
            $message = 'You have successfully completed the test.';
            MoAuthUtilities::show_error_or_success_message($message , 'status');
        } elseif ($response->status == 'FAILED') {
            drupal_set_message(t('The passcode you have entered is incorrect. Please try again.'), 'error');
            return;
        } else {
            $message = 'An error occured while processing your request. Please try again.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }
    
    function send_support_query($form, &$form_state) {
        // Clear all the messages
        drupal_get_messages();
        $email = $form['miniorange_2fa_email_address_support']['#value'];
        $phone = $form['miniorange_2fa_phone_number_support']['#value'];
        $query = $form['miniorange_2fa_support_query_support']['#value'];
        MoAuthUtilities::send_support_query($email, $phone, $query);
    }
}

==> miniorange_2fa-8.x-1.2.tar.gz: miniorange_2fa/src/Form/test_otp_over_email.php <==
<?php

namespace Drupal\miniorange_2fa\Form;

/**
 * @file
 * OTP Over Email(test) functions.
 */
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\miniorange_2fa\MiniorangeUser;
use Drupal\miniorange_2fa\MoAuthUtilities;
use Drupal\miniorange_2fa\AuthenticationType;
use Drupal\miniorange_2fa\AuthenticationAPIHandler;
use Drupal\miniorange_2fa\MiniorangeCustomerProfile;
/**
 * Menu callback for testing OTP Over Email.
 */
class test_otp_over_email extends FormBase
{
    public function getFormId() {
        return 'miniorange_otp_over_email';
    }
    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        $form['markup_top_2'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
        );

        $form['markup_library'] = array(
            '#attached' => array(
                'library' => array(
                    "miniorange_2fa/miniorange_2fa.admin",
                    "miniorange_2fa/miniorange_2fa.license",
                )
            ),
        );

        global $base_url;
        $url = $base_url . '/admin/config/people/miniorange_2fa/setup_twofactor';
        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $custom_attribute = MoAuthUtilities::get_users_custom_attribute($user_id);
        $user_email = $custom_attribute[0]->miniorange_registered_email;
        $user_phone = \Drupal::config('miniorange_2fa.settings')->get('mo_phone');
        $authTypeCode = AuthenticationType::$OTP_OVER_EMAIL['code'];

        $txId_Value = \Drupal::config('miniorange_2fa.settings')->get('txId_Value');
        if($txId_Value == 'EMPTY_VALUE') {
            $messageHeader = 'An OTP has been sent to ' . $user_email . '. Please enter it here to complete the test.';
            $customer = new MiniorangeCustomerProfile();
            $miniorange_user = new MiniorangeUser($customer->getCustomerID(), NULL, $user_phone, NULL, $authTypeCode, $user_email);
            $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
            $response = $auth_api_handler->challenge($miniorange_user);
            if(isset($response->status) && $response->status != 'SUCCESS') {
                $message = 'An error occured while sending passcode. <em>('.$response->message.')</em>';
                MoAuthUtilities::show_error_or_success_message($message , 'error');
            } else{
                \Drupal::messenger()->addMessage(t($messageHeader), 'status');
            }
            //Store txId
            \Drupal::configFactory()->getEditable('miniorange_2fa.settings')->set('txId_Value', $response->txId)->save();
        }

        $form['header']['#markup'] = '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Test OTP Over Email</div></div>';

        $form['mo_auth_otpover_email_token'] = array(
            '#type' => 'textfield',
            '#maxlength' => 6,
            '#attributes' => array(
                'placeholder' => t('Enter passcode.'),
                'class' => array(
                    'mo2f-textbox',
                    'mo2f-textbox-otp'
                ),
                'style' => 'width:200px',
                'autofocus' => 'true'
            ),
        );

        $form['actions_form_submit'] = array(
            '#type' => 'submit',
            '#value' => t('Verify')
        );

        $form['actions_form_cancel'] = array(
            '#markup' => '<span>&nbsp;&nbsp;</span><a href="'.$url.' "> Cancel Test</a>',
        );

        $form['main_layout_div_end'] = array(
            '#markup' => '<br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br></div>',
        );

        MoAuthUtilities::AddsupportTab( $form, $form_state);

        return $form;
    }

    /**
     * Form submit handler for otp over sms validation.
     */
    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {

        // Clear all the messages
      \Drupal::messenger()->deleteAll();

        $txId = \Drupal::config('miniorange_2fa.settings')->get('txId_Value');
        $token = $form['mo_auth_otpover_email_token']['#value'];
        if(empty($token)){
            \Drupal::messenger()->addMessage(t('Please enter passcode first.'), 'error');
            return;
        }

        $user = User::load(\Drupal::currentUser()->id());
        $user_id = $user->id();
        $custom_attribute = MoAuthUtilities::get_users_custom_attribute($user_id);
        $user_email = $custom_attribute[0]->miniorange_registered_email;
        $authTypeCode = AuthenticationType::$OTP_OVER_EMAIL['code'];
        $user_phone = \Drupal::config('miniorange_2fa.settings')->get('mo_phone');

        $customer = new MiniorangeCustomerProfile();
        $miniorange_user = new MiniorangeUser($customer->getCustomerID(), NULL, $user_phone, $authTypeCode, $user_email);
        $auth_api_handler = new AuthenticationAPIHandler($customer->getCustomerID(), $customer->getAPIKey());
        $response = $auth_api_handler->validate($miniorange_user, $txId, $token);

        // read API response
        if ($response->status == 'SUCCESS') {
            $message = 'You have successfully completed the test.';
            MoAuthUtilities::show_error_or_success_message($message , 'status');
        } elseif ($response->status == 'FAILED') {
            \Drupal::messenger()->addMessage(t('The passcode you have entered is incorrect. Please try again.'), 'error');
            return;
        } else {
            $message = 'An error occured while processing your request. Please try again.';
            MoAuthUtilities::show_error_or_success_message($message , 'error');
        }
    }
}
